package org.gcube.data_catalogue.grsf_publish_ws.json.input;

import org.gcube.data_catalogue.grsf_publish_ws.custom_annotations.CustomField;
import org.gcube.data_catalogue.grsf_publish_ws.custom_annotations.Group;
import org.gcube.data_catalogue.grsf_publish_ws.custom_annotations.Tag;
import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Production_System_Type;
import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Status;

import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * A fishery record bean
 * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
 */
public class FisheryRecord extends Common{

	@JsonProperty("fishery_name")
	private String fisheryName;

	@JsonProperty("fishery_id")
	@CustomField(key="Fishery id")
	private String fisheryId;

	@JsonProperty("scientific_name")
	@Tag
	@CustomField(key="Scientific name")
	private String scientificName;

	@JsonProperty("fishing_area")
	@CustomField(key="Fishing area")
	private String fishingArea;

	@JsonProperty("exploiting_stocks")
	@CustomField(key="Exploiting stocks")
	private String exploitingStocks;

	@JsonProperty("management_entity")
	@Tag
	@CustomField(key="Management entity")
	private String managementEntity;

	@JsonProperty("jurisdiction_area")
	@CustomField(key="Jurisdiction Area")
	private String jurisdictionArea;

	@JsonProperty("production_system_type")
	@Group
	@CustomField(key="Production system type")
	private Production_System_Type productionSystemType;

	@JsonProperty("flag_state")
	@Tag
	@CustomField(key="Flag state")
	private String flagState;

	@JsonProperty("fishing_gear")
	@Tag
	@CustomField(key="Fishing gear")
	private String fishingGear;

	@JsonProperty("status")
	@CustomField(key="Status")
	private Status status;

	public FisheryRecord() {
		super();
	}

	/**
	 * @param fisheryName
	 * @param fisheryId
	 * @param scientificName
	 * @param fishingArea
	 * @param exploitingStocks
	 * @param managementEntity
	 * @param jurisdictionArea
	 * @param productionSystemType
	 * @param flagState
	 * @param fishingGear
	 */
	public FisheryRecord(String fisheryName, String fisheryId,
			String scientificName, String fishingArea, String exploitingStocks,
			String managementEntity, String jurisdictionArea,
			Production_System_Type productionSystemType, String flagState,
			String fishingGear) {
		super();
		this.fisheryName = fisheryName;
		this.fisheryId = fisheryId;
		this.scientificName = scientificName;
		this.fishingArea = fishingArea;
		this.exploitingStocks = exploitingStocks;
		this.managementEntity = managementEntity;
		this.jurisdictionArea = jurisdictionArea;
		this.productionSystemType = productionSystemType;
		this.flagState = flagState;
		this.fishingGear = fishingGear;
	}

	public String getFisheryName() {
		return fisheryName;
	}

	public void setFisheryName(String fisheryName) {
		this.fisheryName = fisheryName;
	}

	public String getFisheryId() {
		return fisheryId;
	}

	public void setFisheryId(String fisheryId) {
		this.fisheryId = fisheryId;
	}

	public String getScientificName() {
		return scientificName;
	}

	public void setScientificName(String scientificName) {
		this.scientificName = scientificName;
	}

	public String getFishingArea() {
		return fishingArea;
	}

	public void setFishingArea(String fishingArea) {
		this.fishingArea = fishingArea;
	}

	public String getExploitingStocks() {
		return exploitingStocks;
	}

	public void setExploitingStocks(String exploitingStocks) {
		this.exploitingStocks = exploitingStocks;
	}

	public String getManagementEntity() {
		return managementEntity;
	}

	public void setManagementEntity(String managementEntity) {
		this.managementEntity = managementEntity;
	}

	public String getJurisdictionArea() {
		return jurisdictionArea;
	}

	public void setJurisdictionArea(String jurisdictionArea) {
		this.jurisdictionArea = jurisdictionArea;
	}

	public Production_System_Type getProductionSystemType() {
		return productionSystemType;
	}

	public void setProductionSystemType(Production_System_Type productionSystemType) {
		this.productionSystemType = productionSystemType;
	}

	public String getFlagState() {
		return flagState;
	}

	public void setFlagState(String flagState) {
		this.flagState = flagState;
	}

	public String getFishingGear() {
		return fishingGear;
	}

	public void setFishingGear(String fishingGear) {
		this.fishingGear = fishingGear;
	}

	public Status getStatus() {
		return status;
	}

	public void setStatus(Status status) {
		this.status = status;
	}

	@Override
	public String toString() {
		return "FisheryRecord [" + super.toString() + ", fisheryName=" + fisheryName + ", fisheryId="
				+ fisheryId + ", scientificName=" + scientificName
				+ ", fishingArea=" + fishingArea + ", exploitingStocks="
				+ exploitingStocks + ", managementEntity=" + managementEntity
				+ ", jurisdictionArea=" + jurisdictionArea
				+ ", productionSystemType=" + productionSystemType
				+ ", flagState=" + flagState + ", fishingGear=" + fishingGear
				+ ", status=" + status + "]";
	}

}
