package org.gcube.data_catalogue.grsf_publish_ws.json.input;

import org.gcube.data_catalogue.grsf_publish_ws.custom_annotations.CustomField;
import org.gcube.data_catalogue.grsf_publish_ws.custom_annotations.Group;
import org.gcube.data_catalogue.grsf_publish_ws.custom_annotations.Tag;
import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Abundance_Level;
import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Exploitation_Rate;
import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Status;

import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * A stock record bean
 * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
 */
public class StockRecord extends Common{

	@JsonProperty("stock_name")
	private String stockName;

	@JsonProperty("stock_id")
	@CustomField(key="Stock Id")
	private String stockID;

	@JsonProperty("species_scientific_name")
	@Tag
	@CustomField(key="Species scientific name")
	private String speciesScientificName;

	@JsonProperty("area")
	@CustomField(key="Area")
	private String area;

	@JsonProperty("exploiting_fishery")
	@CustomField(key="Exploiting fishery")
	private String exploitingFishery;

	@JsonProperty("management_entity")
	@CustomField(key="Management entity")
	private String managementEntity;

	@JsonProperty("assessment_methods")
	@CustomField(key="Assessment methods")
	private String assessmentMethods;

	@JsonProperty("state_of_marine_resource")
	@CustomField(key="State of marine resources")
	private String stateOfMarineResource;

	@JsonProperty("exploitation_rate")
	@CustomField(key="Exploitation rate")
	@Group
	private Exploitation_Rate exploitationRate;

	@JsonProperty("abundance_level")
	@CustomField(key="Abundance level")
	@Group
	private Abundance_Level abundanceLevel;

	@JsonProperty("narrative_state_and_trend")
	@CustomField(key="Narrative state and trend")
	private String narrativeStateAndTrend;

	@JsonProperty("scientific_advice")
	@CustomField(key="Scientific advice")
	private String scientificAdvice;

	@JsonProperty("reporting_entity")
	@CustomField(key="Reporting entity")
	private String reportingEntity;

	@JsonProperty("reporting_year")
	@CustomField(key="Reporting year")
	private Long reportingYear;
	
	@JsonProperty("status")
	@Tag
	@CustomField(key="Status")
	private Status status;

	/**
	 * 
	 */
	public StockRecord() {
		super();
	}

	/**
	 * @param stockName
	 * @param stockID
	 * @param speciesScientificName
	 * @param area
	 * @param exploitingFishery
	 * @param managementEntity
	 * @param assessmentMethods
	 * @param stateOfMarineResource
	 * @param exploitationRate
	 * @param abundanceLevel
	 * @param narrativeStateAndTrend
	 * @param scientificAdvice
	 * @param reportingEntity
	 * @param reportingYear
	 */
	public StockRecord(String stockName, String stockID,
			String speciesScientificName, String area,
			String exploitingFishery, String managementEntity,
			String assessmentMethods, String stateOfMarineResource,
			Exploitation_Rate exploitationRate, Abundance_Level abundanceLevel,
			String narrativeStateAndTrend, String scientificAdvice,
			String reportingEntity, Long reportingYear) {
		super();
		this.stockName = stockName;
		this.stockID = stockID;
		this.speciesScientificName = speciesScientificName;
		this.area = area;
		this.exploitingFishery = exploitingFishery;
		this.managementEntity = managementEntity;
		this.assessmentMethods = assessmentMethods;
		this.stateOfMarineResource = stateOfMarineResource;
		this.exploitationRate = exploitationRate;
		this.abundanceLevel = abundanceLevel;
		this.narrativeStateAndTrend = narrativeStateAndTrend;
		this.scientificAdvice = scientificAdvice;
		this.reportingEntity = reportingEntity;
		this.reportingYear = reportingYear;
	}

	public String getStockName() {
		return stockName;
	}

	public void setStockName(String stockName) {
		this.stockName = stockName;
	}

	public String getStockID() {
		return stockID;
	}

	public void setStockID(String stockID) {
		this.stockID = stockID;
	}

	public String getSpeciesScientificName() {
		return speciesScientificName;
	}

	public void setSpeciesScientificName(String speciesScientificName) {
		this.speciesScientificName = speciesScientificName;
	}

	public String getArea() {
		return area;
	}

	public void setArea(String area) {
		this.area = area;
	}

	public String getExploitingFishery() {
		return exploitingFishery;
	}

	public void setExploitingFishery(String exploitingFishery) {
		this.exploitingFishery = exploitingFishery;
	}

	public String getManagementEntity() {
		return managementEntity;
	}

	public void setManagementEntity(String managementEntity) {
		this.managementEntity = managementEntity;
	}

	public String getAssessmentMethods() {
		return assessmentMethods;
	}

	public void setAssessmentMethods(String assessmentMethods) {
		this.assessmentMethods = assessmentMethods;
	}

	public String getStateOfMarineResource() {
		return stateOfMarineResource;
	}

	public void setStateOfMarineResource(String stateOfMarineResource) {
		this.stateOfMarineResource = stateOfMarineResource;
	}

	public Exploitation_Rate getExploitationRate() {
		return exploitationRate;
	}

	public void setExploitationRate(Exploitation_Rate exploitationRate) {
		this.exploitationRate = exploitationRate;
	}

	public Abundance_Level getAbundanceLevel() {
		return abundanceLevel;
	}

	public void setAbundanceLevel(Abundance_Level abundanceLevel) {
		this.abundanceLevel = abundanceLevel;
	}

	public String getNarrativeStateAndTrend() {
		return narrativeStateAndTrend;
	}

	public void setNarrativeStateAndTrend(String narrativeStateAndTrend) {
		this.narrativeStateAndTrend = narrativeStateAndTrend;
	}

	public String getScientificAdvice() {
		return scientificAdvice;
	}

	public void setScientificAdvice(String scientificAdvice) {
		this.scientificAdvice = scientificAdvice;
	}

	public String getReportingEntity() {
		return reportingEntity;
	}

	public void setReportingEntity(String reportingEntity) {
		this.reportingEntity = reportingEntity;
	}

	public Long getReportingYear() {
		return reportingYear;
	}

	public void setReportingYear(Long reportingYear) {
		this.reportingYear = reportingYear;
	}
	
	public Status getStatus() {
		return status;
	}

	public void setStatus(Status status) {
		this.status = status;
	}

	@Override
	public String toString() {
		return "StockRecord [" + super.toString() + ", stockName=" + stockName + ", stockID=" + stockID
				+ ", speciesScientificName=" + speciesScientificName
				+ ", area=" + area + ", exploitingFishery=" + exploitingFishery
				+ ", managementEntity=" + managementEntity
				+ ", assessmentMethods=" + assessmentMethods
				+ ", stateOfMarineResource=" + stateOfMarineResource
				+ ", exploitationRate=" + exploitationRate
				+ ", abundanceLevel=" + abundanceLevel
				+ ", narrativeStateAndTrend=" + narrativeStateAndTrend
				+ ", scientificAdvice=" + scientificAdvice
				+ ", reportingEntity=" + reportingEntity + ", reportingYear="
				+ reportingYear + ", status=" + status + "]";
	}

}
